#!/bin/bash

#External sources
ScriptPath=$(readlink -f $(dirname ${BASH_SOURCE[0]}))
source $ScriptPath"/"lib_extension.sh
source $ScriptPath"/"lib_Installer.sh

#Locals Variables
OracleJvm=1.7.0_55-b13

install_open_java()
{
#Param: $1=jre/jdk $2= version
	sudo apt-get install openjdk-$2-$1
}

uninstall_open_java()
{
	sudo apt-get purge openjdk*
	sudo apt-get autoremove
}

install_oracle_java()
{
#Param: $1=jre/jdk $2=6/7
	ioj_TmpDir=$HOME/.tmpJavaInstall
	ioj_JavaRelease=$2
	ioj_javaVersionNumber=${ioj_JavaRelease:2:1}u${ioj_JavaRelease:6:6}
	ioj_javaFolder=$1${ioj_JavaRelease:0:8}
	ioj_Url="http://download.oracle.com/otn-pub/java/jdk/$ioj_javaVersionNumber"
	ioj_package="$1-${ioj_javaVersionNumber:0:4}-linux-"

	if [ "${varSysInfo:(-2)}"=="64" ]; then
		ioj_package=$ioj_package"x64.tar.gz"
	else
		ioj_package=$ioj_package"i586.tar.gz"
	fi

	# creating temporary folder
	if [ -d "$ioj_TmpDir" ]; then
		rm -r $ioj_TmpDir
	fi
	mkdir $ioj_TmpDir

	#Getting archive and creating jvm
	wget --no-cookies --no-check-certificate --header "Cookie: oraclelicense=accept-securebackup-cookie" -P $ioj_TmpDir "$ioj_Url/$ioj_package"
	tar -xvf $ioj_TmpDir/$ioj_package -C $ioj_TmpDir

	if ! [ -d "/usr/lib/jvm" ]; then
		sudo mkdir -p /usr/lib/jvm
	fi
	sudo mv $ioj_TmpDir/$ioj_javaFolder /usr/lib/jvm/$ioj_javaFolder

	#Linking
	if [ -f /usr/lib/jvm/$ioj_javaFolder/bin/java ]; then
		sudo update-alternatives --install "/usr/bin/java" "java" "/usr/lib/jvm/$ioj_javaFolder/bin/java" 1
		sudo update-alternatives --set java "/usr/lib/jvm/$ioj_javaFolder/bin/java"
	fi
	if [ -f /usr/lib/jvm/$ioj_javaFolder/bin/javac ]; then
		sudo update-alternatives --install "/usr/bin/javac" "javac" "/usr/lib/jvm/$ioj_javaFolder/bin/javac" 1
		sudo update-alternatives --set javac "/usr/lib/jvm/$ioj_javaFolder/bin/javac"
	fi
	if [ -f /usr/lib/jvm/$ioj_javaFolder/bin/javaws ]; then
		sudo update-alternatives --install "/usr/bin/javaws" "javaws" "/usr/lib/jvm/$ioj_javaFolder/bin/javaws" 1
		sudo update-alternatives --set javaws "/usr/lib/jvm/$ioj_javaFolder/bin/javaws"
	fi

	#Cleaning
	rm -r $ioj_TmpDir
	unset ioj_JavaRelease ioj_javaVersionNumber ioj_javaFolder ioj_Url ioj_package
}

remove_oracle_java()
{
#Param: $1=jre/jdk $2=version
	ioj_javaFolder=$1${2:0:8}
	if [ -f /usr/lib/jvm/$ioj_javaFolder/bin/java ]; then
		sudo update-alternatives --remove java "/usr/lib/jvm/$ioj_javaFolder/bin/java"
	fi
	if [ -f /usr/lib/jvm/$ioj_javaFolder/bin/javac ]; then
		sudo update-alternatives --remove javac "/usr/lib/jvm/$ioj_javaFolder/bin/javac"
	fi
	if [ -f /usr/lib/jvm/$ioj_javaFolder/bin/javaws ]; then
		sudo update-alternatives --remove javaws "/usr/lib/jvm/$ioj_javaFolder/bin/javaws"
	fi
	sudo rm -rf "/usr/lib/jvm/$ioj_javaFolder"

	#Cleaning
	unset ioj_javaFolder
}

# Java installer / Configurator
if ! bin_exists "java"; then
	echo "-----------------------------------------"
	echo "-Java environment not found on your system.-"
	echo "-----------------------------------------"
else
	echo "-----------------------------------------"
	echo "-  Java environment found on your system:  -"
	java -version
	javac -version
	echo "-----------------------------------------"
fi

choice="x"
while [ $choice != "0" ];
    do
		echo "Choose Java environment to install :"
		echo "      1-> OpenJDK 7"
		echo "      2-> OpenJRE 7"
		echo "      3-> Java (Oracle) JRE 7"
		echo "      4-> Java (Oracle) JDK 7"
		echo "Choose Java environment to remove :"
		echo "     10-> OpenJDK/JRE"
		echo "     11-> Java (Oracle) JRE 7"
		echo "     12-> Java (Oracle) JDK 7"
		echo
		echo "      0-> - No change -"
		echo
		read -p "your choice :" choice
		case $choice in
			1)install_open_java jdk 7;;
			2)install_open_java jre 7;;
			3)install_oracle_java jre $OracleJvm;;
			4)install_oracle_java jdk $OracleJvm;;
			10)uninstall_open_java;;
			11)remove_oracle_java jre $OracleJvm;;
			12)remove_oracle_java jdk $OracleJvm;;
		esac
done

